Getting Help
!!!!!!!!!!!!

If you run into an issue, have an idea, or just need guidance using AnyVar, we’re happy to help. Please choose the most appropriate channel so we can respond efficiently:

* `Report a bug <https://github.com/biocommons/anyvar/issues/new?template=bug-report.md>`_
* `Request a new feature <https://github.com/biocommons/anyvar/issues/new?template=feature-request.md>`_
* `Ask a question (how-to, usage, clarifications) <https://github.com/biocommons/anyvar/discussions/new?category=q-a>`_

Each link opens a pre-filled template to help you provide the details we need.
